@@ -1,5 +1,8 @@
 ## ----setup, include=FALSE-----------------------------------------------------
+set.seed(123)
 library(INLA)
+inla.setOption(num.threads="1:1")
+inla.setOption(smtp="taucs")
 knitr::opts_chunk$set(echo = TRUE, cache = FALSE)
 
 ## -----------------------------------------------------------------------------
