@@ -1,9 +1,11 @@
 ## ----setup, include=FALSE-----------------------------------------------------
 set.seed(123)
 library(INLA)
+set.seed(123)
+inla.setOption(num.threads="1:1")
+inla.setOption(smtp="taucs")
 library(knitr)
 library(rmarkdown)
-inla.setOption(num.threads=1)
 knitr::opts_chunk$set(echo=TRUE, cache=FALSE, message=FALSE,
 warning=FALSE)
 
