@@ -1,10 +1,11 @@
 ## ----setup, include=FALSE-----------------------------------------------------
+library(INLA)
+set.seed(123)
+inla.setOption(num.threads="1:1")
+inla.setOption(smtp="taucs")
 knitr::opts_chunk$set(echo = TRUE)
 
 ## ---- message = FALSE, warning = FALSE----------------------------------------
-library(INLA)
-inla.setOption(num.threads=1)
-
 # number of observations 
 n = 10
 
