@@ -10,6 +10,9 @@ library(pixmap)
 library(numDeriv)
 library(fields)
 library(INLA)
+set.seed(123)
+inla.setOption(num.threads="1:1")
+inla.setOption(smtp="taucs")
 
 ## ----echo=TRUE,eval=FALSE----------------
 #  formula = y ~  f(idx, model = "rw2", scale.model = TRUE, hyper=..)
@@ -194,7 +197,7 @@ func.munich <- function(a,b,option)
                     Kein.Badkach  + Besond.Bad + Gehobene.Kueche +
                         zim1 + zim2 + zim3 + zim4 + zim5 + zim6 -1
     
-    result =  inla(formula,data=Munich)
+    result =  inla(formula,data=Munich, control.inla = list(h = 0.001))
 }
 
 ## ----echo=FALSE,eval=TRUE----------------
